@@ -38,14 +38,14 @@ public class Figure
 private static final Rectangle PRIVATE_RECT = new Rectangle();
 private static final Point PRIVATE_POINT = new Point();
 private static final int
-	FLAG_VALID = 1,
-	FLAG_OPAQUE = 1 << 1,
-	FLAG_VISIBLE = 1 << 2,
-	FLAG_FOCUSABLE = 1 << 3,
-	FLAG_ENABLED = 1 << 4,
-	FLAG_FOCUS_TRAVERSABLE = 1 << 5;
+	FLAG_VALID = new Integer(1).intValue(),
+	FLAG_OPAQUE = new Integer(1 << 1).intValue(),
+	FLAG_VISIBLE = new Integer(1 << 2).intValue(),
+	FLAG_FOCUSABLE = new Integer(1 << 3).intValue(),
+	FLAG_ENABLED = new Integer(1 << 4).intValue(),
+	FLAG_FOCUS_TRAVERSABLE = new Integer(1 << 5).intValue();
 
-private static final int
+static final int
 	FLAG_REALIZED = 1 << 31;
 
 /**
@@ -55,7 +55,7 @@ private static final int
  * <P>
  * This constant is evaluated at runtime and will not be inlined by the compiler.
  */
-protected static int MAX_FLAG = new Integer(FLAG_FOCUS_TRAVERSABLE).intValue();
+protected static int MAX_FLAG = FLAG_FOCUS_TRAVERSABLE;
 
 /**
  * The rectangular area that this Figure occupies.
@@ -216,7 +216,7 @@ public void addKeyListener(KeyListener listener) {
 }	
 
 /**
- * Prepends the given layout listener to the list of layout listeners.
+ * Appends the given layout listener to the list of layout listeners.
  * @since 3.1
  * @param listener the listener being added
  */
@@ -625,11 +625,9 @@ public Insets getInsets() {
  * @see IFigure#getLayoutManager()
  */
 public LayoutManager getLayoutManager() {
-	LayoutManager manager = layoutManager;
-	while (manager instanceof LayoutNotifier)
-		manager = ((LayoutNotifier)manager).realLayout;
-	
-	return manager;
+	if (layoutManager instanceof LayoutNotifier)
+		return ((LayoutNotifier)layoutManager).realLayout;
+	return layoutManager;
 }
 
 /**
@@ -915,8 +913,6 @@ public boolean intersects(Rectangle rect) {
  * @see IFigure#invalidate()
  */
 public void invalidate() {
-	if (!isValid()) 
-		return;
 	if (layoutManager != null)
 		layoutManager.invalidate();
 	setValid(false);
@@ -1240,7 +1236,7 @@ public void removeKeyListener(KeyListener listener) {
 }
 
 /**
- * Removes the most recently added occurence of the given listener.
+ * Removes the first occurence of the given listener.
  * @since 3.1
  * @param listener the listener being removed
  */
@@ -1531,7 +1527,10 @@ public void setForegroundColor(Color fg) {
  * @see IFigure#setLayoutManager(LayoutManager)
  */
 public void setLayoutManager(LayoutManager manager) {
-	layoutManager = manager;
+	if (layoutManager instanceof LayoutNotifier)
+		((LayoutNotifier)layoutManager).realLayout = manager;
+	else
+		layoutManager = manager;
 	revalidate();
 }
 
