@@ -10,7 +10,8 @@
  *******************************************************************************/
 package org.eclipse.draw2d.text;
 
-import java.text.BreakIterator;
+
+import com.ibm.icu.text.BreakIterator;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Font;
@@ -315,7 +316,6 @@ public static int wrapFragmentInContext(TextFragmentBox frag, String string,
 					break out;
 
 				default:
-				case ParagraphTextLayout.WORD_WRAP_SOFT :
 					result = min;
 					break;
 			}
